#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const prompts_1 = require("@clack/prompts");
const child_process_utils_1 = require("create-nx-workspace/src/utils/child-process-utils");
const package_manager_1 = require("create-nx-workspace/src/utils/package-manager");
const node_path_1 = require("node:path");
const custom_create_workspace_1 = require("../lib/custom-create-workspace");
const final_note_1 = require("../lib/final-note");
const get_args_1 = require("../lib/get-args");
function main() {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const pm = (0, package_manager_1.detectInvokedPackageManager)();
        const args = yield (0, get_args_1.getArgs)(process.argv, pm);
        if (!args.dryRun) {
            const { directory } = yield (0, custom_create_workspace_1.customCreateWorkspace)(`${args.package}`, {
                anchor: args.anchor,
                anchorName: args.anchorName,
                anchorProgram: args.anchorProgram,
                commit: {
                    name: '',
                    email: '',
                    message: 'chore: initial commit',
                },
                dryRun: args.dryRun,
                name: args.name,
                nxCloud: 'skip',
                packageManager: args.packageManager,
                ui: args.ui,
                webName: args.webName,
                webPort: args.webPort,
            }, () => tslib_1.__awaiter(this, void 0, void 0, function* () {
                if (args.anchor === 'none' || !args.anchorBuild) {
                    return;
                }
                const s = (0, prompts_1.spinner)();
                s.start('Building anchor...');
                try {
                    yield (0, child_process_utils_1.execAndWait)(`anchor keys sync`, (0, node_path_1.join)(args.name, args.anchorName));
                    yield (0, child_process_utils_1.execAndWait)(`npx nx run ${args.anchorName}:build`, (0, node_path_1.join)(args.name));
                    s.stop('Anchor built.');
                }
                catch (e) {
                    s.stop('Anchor build failed.');
                    prompts_1.log.warn('Do you have Rust and Anchor installed?');
                }
            }));
            const target = directory.replace(process.cwd(), '.');
            (0, prompts_1.note)((0, final_note_1.finalNote)(Object.assign(Object.assign({}, args), { target })), 'Installation successful!');
        }
        else {
            (0, prompts_1.note)(JSON.stringify(args, null, 2), 'Dry run, no changes were made.');
            (0, prompts_1.note)((0, final_note_1.finalNote)(Object.assign(Object.assign({}, args), { target: './dry-run' })), 'Installation successful!');
        }
        (0, prompts_1.outro)('Good luck with your project!');
    });
}
main();
//# sourceMappingURL=index.js.map