"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.customCreateSandbox = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const child_process_utils_1 = require("create-nx-workspace/src/utils/child-process-utils");
const error_utils_1 = require("create-nx-workspace/src/utils/error-utils");
const package_manager_1 = require("create-nx-workspace/src/utils/package-manager");
const fs_1 = require("fs");
const versions_1 = require("nx/src/utils/versions");
const path_1 = require("path");
const tmp_1 = require("tmp");
/**
 * Creates a temporary directory and installs Nx in it.
 * @param packageManager package manager to use
 * @returns directory where Nx is installed
 */
function customCreateSandbox(packageManager) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { install, preInstall } = (0, package_manager_1.getPackageManagerCommand)(packageManager);
        const tmpDir = (0, tmp_1.dirSync)().name;
        try {
            (0, fs_1.writeFileSync)((0, path_1.join)(tmpDir, 'package.json'), JSON.stringify({
                dependencies: {
                    nx: versions_1.nxVersion,
                    '@nx/workspace': versions_1.nxVersion,
                },
                license: 'MIT',
            }));
            (0, package_manager_1.generatePackageManagerFiles)(tmpDir, packageManager);
            if (preInstall) {
                yield (0, child_process_utils_1.execAndWait)(preInstall, tmpDir);
            }
            yield (0, child_process_utils_1.execAndWait)(install, tmpDir);
        }
        catch (e) {
            if (e instanceof Error) {
                devkit_1.output.error({
                    title: `Failed to install dependencies`,
                    bodyLines: (0, error_utils_1.mapErrorToBodyLines)(e),
                });
            }
            else {
                console.error(e);
            }
            process.exit(1);
        }
        return tmpDir;
    });
}
exports.customCreateSandbox = customCreateSandbox;
//# sourceMappingURL=custom-create-sandbox.js.map