"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.customCreateWorkspace = void 0;
const tslib_1 = require("tslib");
const prompts_1 = require("@clack/prompts");
const create_preset_1 = require("create-nx-workspace/src/create-preset");
const child_process_utils_1 = require("create-nx-workspace/src/utils/child-process-utils");
const error_utils_1 = require("create-nx-workspace/src/utils/error-utils");
const git_1 = require("create-nx-workspace/src/utils/git/git");
const get_third_party_preset_1 = require("create-nx-workspace/src/utils/preset/get-third-party-preset");
const custom_create_empty_workspace_1 = require("./custom-create-empty-workspace");
const custom_create_sandbox_1 = require("./custom-create-sandbox");
function customCreateWorkspace(preset, options, afterCreatePreset) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { packageManager, name, skipGit = false, defaultBase = 'main', commit } = options;
        const spin1 = (0, prompts_1.spinner)();
        spin1.start(`Creating new workspace with ${packageManager}`);
        const tmpDir = yield (0, custom_create_sandbox_1.customCreateSandbox)(packageManager);
        // nx new requires preset currently. We should probably make it optional.
        const directory = yield (0, custom_create_empty_workspace_1.customCreateEmptyWorkspace)(tmpDir, name, packageManager, Object.assign(Object.assign({}, options), { preset }));
        spin1.stop(`Successfully created workspace with ${packageManager}.`);
        // Delete the generated README.md
        yield (0, child_process_utils_1.execAndWait)('rm README.md', directory);
        // If the preset is a third-party preset, we need to call createPreset to install it
        // For first-party presets, it will created by createEmptyWorkspace instead.
        // In createEmptyWorkspace, it will call `nx new` -> `@nx/workspace newGenerator` -> `@nx/workspace generatePreset`.
        const spin3 = (0, prompts_1.spinner)();
        spin3.start(`Installing preset ${preset}`);
        const thirdPartyPreset = yield (0, get_third_party_preset_1.getThirdPartyPreset)(preset);
        if (thirdPartyPreset) {
            // Hide the stdout of createPreset
            yield (0, create_preset_1.createPreset)(thirdPartyPreset, options, packageManager, directory);
        }
        yield afterCreatePreset(options);
        if (!skipGit && commit) {
            try {
                yield (0, git_1.initializeGitRepo)(directory, { defaultBase, commit });
                spin3.stop(`Successfully installed preset ${preset}.`);
            }
            catch (e) {
                if (e instanceof Error) {
                    console.error({
                        title: 'Could not initialize git repository',
                        bodyLines: (0, error_utils_1.mapErrorToBodyLines)(e),
                    });
                }
                else {
                    console.error(e);
                }
                spin3.stop(`Failed to install preset ${preset} .`);
            }
        }
        return {
            directory,
        };
    });
}
exports.customCreateWorkspace = customCreateWorkspace;
//# sourceMappingURL=custom-create-workspace.js.map