"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.finalNote = void 0;
const chalk_1 = require("chalk");
const validate_anchor_version_1 = require("./validate-anchor-version");
function finalNote(args) {
    const lines = [
        `That's it!`,
        `Change to your new directory and start developing:`,
        msg(`cd ${args.target}`),
        `Start the ${presetLabel(args.preset)} app:`,
        cmd(args.packageManager, 'dev'),
    ];
    if (args.anchor !== 'none') {
        lines.push(...[`Run Anchor commands:`, cmd(args.packageManager, 'anchor build | test | localnet | deploy')]);
        lines.push(...[`Generate more features using the following command:`, cmd(args.packageManager, 'feature')]);
        const { requiredVersion, valid, version } = (0, validate_anchor_version_1.validateAnchorVersion)();
        if (!version) {
            lines.push(...[
                (0, chalk_1.bold)((0, chalk_1.yellowBright)(`Could not find Anchor version. Please install Anchor.`)),
                'https://www.anchor-lang.com/docs/installation',
            ]);
        }
        else if (!valid) {
            lines.push(...[
                (0, chalk_1.yellowBright)(`Found Anchor version ${version}. Please upgrade to Anchor ${requiredVersion}.`),
                'https://www.anchor-lang.com/release-notes/0.30.0',
            ]);
        }
        else {
            lines.push((0, chalk_1.greenBright)(`Found Anchor version ${version}. Great!`));
        }
    }
    return lines.join('\n\n');
}
exports.finalNote = finalNote;
function presetLabel(preset) {
    switch (preset) {
        case 'next':
            return 'Next.js';
        case 'react':
            return 'React';
        default:
            return preset;
    }
}
function cmd(pm, command) {
    return msg(`${pm} run ${command}`);
}
function msg(message) {
    return (0, chalk_1.bold)((0, chalk_1.magentaBright)(message));
}
//# sourceMappingURL=final-note.js.map