"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUiLibraries = exports.getPrompts = void 0;
const prompts_1 = require("@clack/prompts");
const validate_project_name_1 = require("./validate-project-name");
function getPrompts({ anchorTemplates, options, presets, }) {
    return (0, prompts_1.group)({
        name: () => {
            if (options.name) {
                prompts_1.log.success(`Project name: ${options.name}`);
                return Promise.resolve(options.name);
            }
            return (0, prompts_1.text)({
                message: 'Enter project name',
                validate: validate_project_name_1.validateProjectName,
            });
        },
        preset: () => {
            var _a;
            if (options.preset) {
                prompts_1.log.success(`Preset: ${(_a = presets.find((p) => p.value === options.preset)) === null || _a === void 0 ? void 0 : _a.label}`);
                return Promise.resolve(options.preset);
            }
            return (0, prompts_1.select)({
                message: 'Select a preset',
                options: presets.map(({ label, value }) => ({ label, value })),
            });
        },
        ui: ({ results }) => {
            var _a, _b, _c;
            const preset = (_a = results === null || results === void 0 ? void 0 : results.preset) !== null && _a !== void 0 ? _a : options.preset;
            const libs = getUiLibraries(preset);
            if (options.ui) {
                prompts_1.log.success(`UI library: ${(_b = libs.find((l) => l.value === options.ui)) === null || _b === void 0 ? void 0 : _b.label}`);
                return Promise.resolve(options.ui);
            }
            return (0, prompts_1.select)({
                message: 'Select a UI library',
                options: getUiLibraries(preset),
                initialValue: (_c = libs.find((lib) => lib.value !== 'none')) === null || _c === void 0 ? void 0 : _c.value,
            });
        },
        anchor: () => {
            if (options.anchor) {
                const anchor = anchorTemplates.find((a) => a.value === options.anchor);
                prompts_1.log.success(`Anchor template: ${anchor.label}`);
                return Promise.resolve(options.anchor);
            }
            return (0, prompts_1.select)({
                message: 'Select an Anchor template',
                options: anchorTemplates.map(({ label, value }) => ({ label, value })),
            });
        },
        anchorProgram: ({ results }) => {
            var _a;
            if (options.anchor) {
                const anchorProgram = options.anchorProgram.length ? options.anchorProgram : (_a = results.name) !== null && _a !== void 0 ? _a : 'my-program';
                prompts_1.log.success(`Anchor program name: ${anchorProgram}`);
                return Promise.resolve(anchorProgram);
            }
        },
    }, {
        onCancel: () => {
            (0, prompts_1.cancel)('Operation cancelled.');
            process.exit(0);
        },
    });
}
exports.getPrompts = getPrompts;
function getUiLibraries(preset) {
    switch (preset) {
        case 'next':
            return [
                { label: 'None', value: 'none' },
                { label: 'Tailwind', value: 'tailwind' },
            ];
        case 'react':
            return [
                { label: 'None', value: 'none' },
                { label: 'Tailwind', value: 'tailwind' },
            ];
        default:
            return [];
    }
}
exports.getUiLibraries = getUiLibraries;
//# sourceMappingURL=get-prompts.js.map